@@ -23,6 +23,7 @@
 #include "neonrequest.hpp"
 
 #include <utils/davix_logger_internal.hpp>
+#include <utils/davix_gcloud_utils.hpp>
 #include <libs/time_utils.h>
 #include <ne_redirect.h>
 #include <ne_request.h>
@@ -66,6 +67,8 @@ void configureRequestParamsProto(const Uri &uri, RequestParams &params){
             params.setProtocol(RequestProtocol::AwsS3);
         }else if ( proto.compare(0, 3,"dav") ==0){
             params.setProtocol(RequestProtocol::Webdav);
+        }else if ( proto.compare(0, 6, "gcloud") ==0) {
+            params.setProtocol(RequestProtocol::Gcloud);
         }
     }
 
@@ -231,6 +234,10 @@ int NEONRequest::createRequest(DavixError** err){
     if(params.getProtocol() == RequestProtocol::Azure)
         configureAzureParams();
 
+    // configure gcloud params if needed
+    if(params.getProtocol() == RequestProtocol::Gcloud)
+        configureGcloudParams();
+
     _req= ne_request_create(_neon_sess->get_ne_sess(), _request_type.c_str(), _current->getPathAndQuery().c_str());
     configureRequest();
 
@@ -358,6 +365,11 @@ void NEONRequest::configureAzureParams(){
     _current= std::shared_ptr<Uri>(new Uri(signed_url));
 }
 
+void NEONRequest::configureGcloudParams() {
+    Uri signed_url = gcloud::signURI(params.getGcloudCredentials(), _request_type, *_current, _headers_field, NEON_S3_SIGN_DURATION);
+    _current= std::shared_ptr<Uri>(new Uri(signed_url));
+}
+
 int NEONRequest::processRedirection(int neonCode, DavixError **err){
     int end_status = -1;
     if (this->params.getTransparentRedirectionSupport()) {
@@ -456,7 +468,7 @@ int NEONRequest::negotiateRequest(DavixError** err){
                     params.getAcceptedRetryDelay() << " seconds before retrying. (attempt " <<
                     _accepted_202_retries << " out of " << params.getAcceptedRetry() << ")" << std::endl;
                   sleep(params.getAcceptedRetryDelay());
-                  requestCleanup();
+                  endRequest(NULL);
                   return startRequest(err);
                 }
                 goto default_label;
@@ -770,7 +782,7 @@ dav_ssize_t NEONRequest::readLine(char* buffer, dav_size_t max_size, DavixError*
        return (ret >= 0)?(ret + n_bytes):-1;
     }
 
-    if( ( ret = readSegment(buffer, max_size, err)) >= 0){
+    if( ( ret = readSegment(buffer, max_size, true, err)) >= 0){
         // search for crlf
         char* p_endline;
         p_endline = std::find(buffer, buffer+ret, '\n');
@@ -784,23 +796,31 @@ dav_ssize_t NEONRequest::readLine(char* buffer, dav_size_t max_size, DavixError*
 }
 
 
-dav_ssize_t NEONRequest::readSegment(char* p_buff, dav_size_t size_read,  DavixError**err){
+dav_ssize_t NEONRequest::readSegment(char* p_buff, dav_size_t size_read, bool stop_at_line_boundary, DavixError**err){
     DavixError* tmp_err=NULL;
     dav_ssize_t ret, tmp_ret;
     dav_size_t s_read= size_read;
     ret = tmp_ret = 0;
     DAVIX_SLOG(DAVIX_LOG_TRACE, DAVIX_LOG_HTTP, "Davix::Request::readSegment: want to read {} bytes ", size_read);
+    bool early_stop = false;
 
     do{
         tmp_ret= readBlock(p_buff, s_read, &tmp_err);
-        if(tmp_ret > 0){ // tmp_ret bytes readed
+
+        if(tmp_ret > 0 && std::find(p_buff, p_buff+tmp_ret, '\n') != p_buff+tmp_ret) {
+            early_stop = true;
+        }
+
+        if(tmp_ret > 0){ // tmp_ret bytes read
             ret += tmp_ret;
         }
+
         if(ret > 0 && ret < (dav_ssize_t) size_read){
             p_buff+= tmp_ret;
             s_read -= tmp_ret;
         }
-    }while( tmp_ret > 0
+
+    }while( !early_stop && tmp_ret > 0
             &&  ret < (dav_ssize_t) size_read);
 
     if(tmp_err){
